Struct near_pool_v01::PoolIteratorWrapper [−][src]
pub struct PoolIteratorWrapper<'a> { /* fields omitted */ }Expand description
PoolIterator is a structure to pull transactions from the pool.
It implements PoolIterator trait that iterates over transaction groups one by one.
When the wrapper is dropped the remaining transactions are returned back to the pool.
Implementations